@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -41,7 +42,7 @@
 #include <unocrsrhelper.hxx>
 #include <doc.hxx>
 #include <ndtxt.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
 #include <vcl/svapp.hxx>
 #include <docsh.hxx>
 
@@ -60,10 +61,6 @@
 using namespace ::com::sun::star;
 using ::rtl::OUString;
 
-
-/* -----------------------------01.12.00 18:09--------------------------------
-
- ---------------------------------------------------------------------------*/
 class SwParaSelection
 {
     SwCursor & m_rCursor;
@@ -101,11 +98,9 @@ SwParaSelection::~SwParaSelection()
     }
 }
 
-
 /******************************************************************
  * forward declarations
  ******************************************************************/
-
 beans::PropertyState lcl_SwXParagraph_getPropertyState(
                             const SwTxtNode& rTxtNode,
                             const SwAttrSet** ppSet,
@@ -116,7 +111,6 @@ beans::PropertyState lcl_SwXParagraph_getPropertyState(
 /******************************************************************
  * SwXParagraph
  ******************************************************************/
-
 class SwXParagraph::Impl
     : public SwClient
 {
@@ -151,7 +145,7 @@ public:
         return static_cast<const SwTxtNode*>(GetRegisteredIn());
     }
           SwTxtNode * GetTxtNode()       {
-        return static_cast<SwTxtNode*>(pRegisteredIn);
+        return static_cast<SwTxtNode*>(GetRegisteredInNonConst());
     }
 
     SwTxtNode & GetTxtNodeOrThrow() {
@@ -183,16 +177,13 @@ public:
             const uno::Sequence< ::rtl::OUString >& rPropertyNames,
             bool bDirectValuesOnly)
         throw (uno::RuntimeException);
-
+protected:
     // SwClient
-    virtual void    Modify(SfxPoolItem *pOld, SfxPoolItem *pNew);
+    virtual void Modify(const SfxPoolItem *pOld, const SfxPoolItem *pNew);
 
 };
 
-/*-- 11.12.98 08:12:58---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
-void SwXParagraph::Impl::Modify(SfxPoolItem *pOld, SfxPoolItem *pNew)
+void SwXParagraph::Impl::Modify( const SfxPoolItem *pOld, const SfxPoolItem *pNew )
 {
     ClientModify(this, pOld, pNew);
     if (!GetRegisteredIn())
@@ -201,17 +192,11 @@ void SwXParagraph::Impl::Modify(SfxPoolItem *pOld, SfxPoolItem *pNew)
     }
 }
 
-/*-- 11.12.98 08:12:47---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 SwXParagraph::SwXParagraph()
     : m_pImpl( new SwXParagraph::Impl(*this) )
 {
 }
 
-/*-- 11.12.98 08:12:47---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 SwXParagraph::SwXParagraph(
         uno::Reference< text::XText > const & xParent,
         SwTxtNode & rTxtNode,
@@ -221,9 +206,6 @@ SwXParagraph::SwXParagraph(
 {
 }
 
-/*-- 11.12.98 08:12:48---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 SwXParagraph::~SwXParagraph()
 {
 }
@@ -290,17 +272,12 @@ bool SwXParagraph::SelectPaM(SwPaM & rPaM)
     return true;
 }
 
-/* -----------------------------13.03.00 12:15--------------------------------
-
- ---------------------------------------------------------------------------*/
 const uno::Sequence< sal_Int8 > & SwXParagraph::getUnoTunnelId()
 {
     static uno::Sequence< sal_Int8 > aSeq = ::CreateUnoTunnelId();
     return aSeq;
 }
-/* -----------------------------10.03.00 18:04--------------------------------
 
- ---------------------------------------------------------------------------*/
 sal_Int64 SAL_CALL
 SwXParagraph::getSomething(const uno::Sequence< sal_Int8 >& rId)
 throw (uno::RuntimeException)
@@ -308,17 +285,12 @@ throw (uno::RuntimeException)
     return ::sw::UnoTunnelImpl<SwXParagraph>(rId, this);
 }
 
-/* -----------------------------06.04.00 16:37--------------------------------
-
- ---------------------------------------------------------------------------*/
 OUString SAL_CALL
 SwXParagraph::getImplementationName() throw (uno::RuntimeException)
 {
     return C2U("SwXParagraph");
 }
-/* -----------------------------06.04.00 16:37--------------------------------
 
- ---------------------------------------------------------------------------*/
 static char const*const g_ServicesParagraph[] =
 {
     "com.sun.star.text.TextContent",
@@ -330,8 +302,9 @@ static char const*const g_ServicesParagraph[] =
     "com.sun.star.style.ParagraphPropertiesAsian",
     "com.sun.star.style.ParagraphPropertiesComplex",
 };
+
 static const size_t g_nServicesParagraph(
-    sizeof(g_ServicesParagraph)/sizeof(g_ServicesParagraph[0]));
+    SAL_N_ELEMENTS(g_ServicesParagraph));
 
 sal_Bool SAL_CALL
 SwXParagraph::supportsService(const OUString& rServiceName)
@@ -340,9 +313,7 @@ throw (uno::RuntimeException)
     return ::sw::SupportsServiceImpl(
             g_nServicesParagraph, g_ServicesParagraph, rServiceName);
 }
-/* -----------------------------06.04.00 16:37--------------------------------
 
- ---------------------------------------------------------------------------*/
 uno::Sequence< OUString > SAL_CALL
 SwXParagraph::getSupportedServiceNames() throw (uno::RuntimeException)
 {
@@ -350,9 +321,6 @@ SwXParagraph::getSupportedServiceNames() throw (uno::RuntimeException)
             g_nServicesParagraph, g_ServicesParagraph);
 }
 
-/* -----------------------------11.07.00 14:48--------------------------------
-
- ---------------------------------------------------------------------------*/
 void
 SwXParagraph::attachToText(SwXText & rParent, SwTxtNode & rTxtNode)
 {
@@ -372,22 +340,17 @@ SwXParagraph::attachToText(SwXText & rParent, SwTxtNode & rTxtNode)
     }
 }
 
-/*-- 11.12.98 08:12:49---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 uno::Reference< beans::XPropertySetInfo > SAL_CALL
 SwXParagraph::getPropertySetInfo()
 throw (uno::RuntimeException)
 {
-    vos::OGuard g(Application::GetSolarMutex());
+    SolarMutexGuard g;
 
     static uno::Reference< beans::XPropertySetInfo > xRef =
         m_pImpl->m_rPropSet.getPropertySetInfo();
     return xRef;
 }
-/*-- 11.12.98 08:12:49---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SAL_CALL
 SwXParagraph::setPropertyValue(const OUString& rPropertyName,
         const uno::Any& rValue)
@@ -395,7 +358,7 @@ throw (beans::UnknownPropertyException, beans::PropertyVetoException,
     lang::IllegalArgumentException, lang::WrappedTargetException,
     uno::RuntimeException )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     uno::Sequence<OUString> aPropertyNames(1);
     aPropertyNames.getArray()[0] = rPropertyName;
     uno::Sequence<uno::Any> aValues(1);
@@ -403,24 +366,19 @@ throw (beans::UnknownPropertyException, beans::PropertyVetoException,
     m_pImpl->SetPropertyValues_Impl( aPropertyNames, aValues );
 }
 
-/*-- 11.12.98 08:12:49---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 uno::Any
 SwXParagraph::getPropertyValue(const OUString& rPropertyName)
 throw (beans::UnknownPropertyException, lang::WrappedTargetException,
     uno::RuntimeException )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     uno::Sequence<OUString> aPropertyNames(1);
     aPropertyNames.getArray()[0] = rPropertyName;
     const uno::Sequence< uno::Any > aRet =
         m_pImpl->GetPropertyValues_Impl(aPropertyNames);
     return aRet.getConstArray()[0];
 }
-/* -----------------------------02.04.01 11:43--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwXParagraph::Impl::SetPropertyValues_Impl(
     const uno::Sequence< OUString >& rPropertyNames,
     const uno::Sequence< uno::Any >& rValues )
@@ -465,7 +423,7 @@ void SAL_CALL SwXParagraph::setPropertyValues(
 throw (beans::PropertyVetoException, lang::IllegalArgumentException,
     lang::WrappedTargetException, uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     // workaround for bad designed API
     try
@@ -482,9 +440,6 @@ throw (beans::PropertyVetoException, lang::IllegalArgumentException,
     }
 }
 
-/* -----------------------------02.04.01 11:43--------------------------------
-
- ---------------------------------------------------------------------------*/
 uno::Sequence< uno::Any > SwXParagraph::Impl::GetPropertyValues_Impl(
         const uno::Sequence< OUString > & rPropertyNames )
 throw (beans::UnknownPropertyException, lang::WrappedTargetException,
@@ -526,14 +481,11 @@ throw (beans::UnknownPropertyException, lang::WrappedTargetException,
     return aValues;
 }
 
-/* -----------------------------04.11.03 11:43--------------------------------
-
- ---------------------------------------------------------------------------*/
 uno::Sequence< uno::Any > SAL_CALL
 SwXParagraph::getPropertyValues(const uno::Sequence< OUString >& rPropertyNames)
 throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     uno::Sequence< uno::Any > aValues;
 
     // workaround for bad designed API
@@ -557,41 +509,28 @@ throw (uno::RuntimeException)
     return aValues;
 }
 
-/* -----------------------------02.04.01 11:43--------------------------------
-
- ---------------------------------------------------------------------------*/
 void SAL_CALL SwXParagraph::addPropertiesChangeListener(
     const uno::Sequence< OUString >& /*aPropertyNames*/,
     const uno::Reference< beans::XPropertiesChangeListener >& /*xListener*/ )
 throw (uno::RuntimeException)
 {
-    OSL_ENSURE(false,
-        "SwXParagraph::addPropertiesChangeListener(): not implemented");
+    OSL_FAIL("SwXParagraph::addPropertiesChangeListener(): not implemented");
 }
-/* -----------------------------02.04.01 11:43--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SAL_CALL SwXParagraph::removePropertiesChangeListener(
     const uno::Reference< beans::XPropertiesChangeListener >& /*xListener*/ )
 throw (uno::RuntimeException)
 {
-    OSL_ENSURE(false,
-        "SwXParagraph::removePropertiesChangeListener(): not implemented");
+    OSL_FAIL("SwXParagraph::removePropertiesChangeListener(): not implemented");
 }
-/* -----------------------------02.04.01 11:43--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SAL_CALL SwXParagraph::firePropertiesChangeEvent(
     const uno::Sequence< OUString >& /*aPropertyNames*/,
     const uno::Reference< beans::XPropertiesChangeListener >& /*xListener*/ )
         throw(uno::RuntimeException)
 {
-    OSL_ENSURE(false,
-        "SwXParagraph::firePropertiesChangeEvent(): not implemented");
+    OSL_FAIL("SwXParagraph::firePropertiesChangeEvent(): not implemented");
 }
-/* -----------------------------25.09.03 11:09--------------------------------
-
- ---------------------------------------------------------------------------*/
 
 /* disabled for #i46921# */
 
@@ -601,7 +540,7 @@ SwXParagraph::setPropertyValuesTolerant(
         const uno::Sequence< uno::Any >& rValues )
 throw (lang::IllegalArgumentException, uno::RuntimeException)
 {
-    vos::OGuard aGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aGuard;
 
     if (rPropertyNames.getLength() != rValues.getLength())
     {
@@ -612,7 +551,7 @@ throw (lang::IllegalArgumentException, uno::RuntimeException)
 
     //SwNode& rTxtNode = pUnoCrsr->GetPoint()->nNode.GetNode();
     //const SwAttrSet& rAttrSet = ((SwTxtNode&)rTxtNode).GetSwAttrSet();
-    //USHORT nAttrCount = rAttrSet.Count();
+    //sal_uInt16 nAttrCount = rAttrSet.Count();
 
     const sal_Int32 nProps = rPropertyNames.getLength();
     const OUString *pProp = rPropertyNames.getConstArray();
@@ -664,7 +603,7 @@ throw (lang::IllegalArgumentException, uno::RuntimeException)
         catch (beans::UnknownPropertyException &)
         {
             // should not occur because property was searched for before
-            DBG_ERROR( "unexpected exception catched" );
+            OSL_FAIL( "unexpected exception catched" );
             pFailed[ nFailed++ ].Result =
                 beans::TolerantPropertySetResultType::UNKNOWN_PROPERTY;
         }
@@ -689,13 +628,12 @@ throw (lang::IllegalArgumentException, uno::RuntimeException)
     return aFailed;
 }
 
-
 uno::Sequence< beans::GetPropertyTolerantResult > SAL_CALL
 SwXParagraph::getPropertyValuesTolerant(
         const uno::Sequence< OUString >& rPropertyNames )
 throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aGuard;
 
     uno::Sequence< beans::GetDirectPropertyTolerantResult > aTmpRes(
         m_pImpl->GetPropertyValuesTolerant_Impl( rPropertyNames, false ) );
@@ -713,25 +651,23 @@ throw (uno::RuntimeException)
     return aRes;
 }
 
-
 uno::Sequence< beans::GetDirectPropertyTolerantResult > SAL_CALL
 SwXParagraph::getDirectPropertyValuesTolerant(
         const uno::Sequence< OUString >& rPropertyNames )
 throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aGuard;
 
     return m_pImpl->GetPropertyValuesTolerant_Impl( rPropertyNames, true );
 }
 
-
 uno::Sequence< beans::GetDirectPropertyTolerantResult >
 SwXParagraph::Impl::GetPropertyValuesTolerant_Impl(
         const uno::Sequence< OUString >& rPropertyNames,
         bool bDirectValuesOnly )
 throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aGuard;
 
     SwTxtNode & rTxtNode(GetTxtNodeOrThrow());
 
@@ -820,7 +756,7 @@ throw (uno::RuntimeException)
         catch (beans::UnknownPropertyException &)
         {
             // should not occur because property was searched for before
-            DBG_ERROR( "unexpected exception caught" );
+            OSL_FAIL( "unexpected exception caught" );
             rResult.Result = beans::TolerantPropertySetResultType::UNKNOWN_PROPERTY;
         }
         catch (lang::IllegalArgumentException &)
@@ -843,11 +779,8 @@ throw (uno::RuntimeException)
     return aResult;
 }
 
-/* -----------------------------12.09.00 11:09--------------------------------
-
- ---------------------------------------------------------------------------*/
 bool ::sw::GetDefaultTextContentValue(
-        uno::Any& rAny, const OUString& rPropertyName, USHORT nWID)
+        uno::Any& rAny, const OUString& rPropertyName, sal_uInt16 nWID)
 {
     if(!nWID)
     {
@@ -858,7 +791,7 @@ bool ::sw::GetDefaultTextContentValue(
         else if(rPropertyName.equalsAsciiL( SW_PROP_NAME(UNO_NAME_TEXT_WRAP)))
             nWID = FN_UNO_TEXT_WRAP;
         else
-            return FALSE;
+            return sal_False;
     }
 
     switch(nWID)
@@ -873,13 +806,11 @@ bool ::sw::GetDefaultTextContentValue(
         }
         break;
         default:
-            return FALSE;
+            return sal_False;
     }
-    return TRUE;
+    return sal_True;
 }
-/*-- 11.12.98 08:12:50---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SAL_CALL
 SwXParagraph::addPropertyChangeListener(
         const ::rtl::OUString& /*rPropertyName*/,
@@ -887,13 +818,9 @@ SwXParagraph::addPropertyChangeListener(
 throw (beans::UnknownPropertyException, lang::WrappedTargetException,
     uno::RuntimeException)
 {
-    OSL_ENSURE(false,
-        "SwXParagraph::addPropertyChangeListener(): not implemented");
+    OSL_FAIL("SwXParagraph::addPropertyChangeListener(): not implemented");
 }
 
-/*-- 11.12.98 08:12:50---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 void SAL_CALL
 SwXParagraph::removePropertyChangeListener(
         const ::rtl::OUString& /*rPropertyName*/,
@@ -901,13 +828,9 @@ SwXParagraph::removePropertyChangeListener(
 throw (beans::UnknownPropertyException, lang::WrappedTargetException,
     uno::RuntimeException)
 {
-    OSL_ENSURE(false,
-        "SwXParagraph::removePropertyChangeListener(): not implemented");
+    OSL_FAIL("SwXParagraph::removePropertyChangeListener(): not implemented");
 }
 
-/*-- 11.12.98 08:12:50---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 void SAL_CALL
 SwXParagraph::addVetoableChangeListener(
         const ::rtl::OUString& /*rPropertyName*/,
@@ -915,13 +838,9 @@ SwXParagraph::addVetoableChangeListener(
 throw (beans::UnknownPropertyException, lang::WrappedTargetException,
     uno::RuntimeException)
 {
-    OSL_ENSURE(false,
-        "SwXParagraph::addVetoableChangeListener(): not implemented");
+    OSL_FAIL("SwXParagraph::addVetoableChangeListener(): not implemented");
 }
 
-/*-- 11.12.98 08:12:51---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 void SAL_CALL
 SwXParagraph::removeVetoableChangeListener(
         const ::rtl::OUString& /*rPropertyName*/,
@@ -929,11 +848,9 @@ SwXParagraph::removeVetoableChangeListener(
 throw (beans::UnknownPropertyException, lang::WrappedTargetException,
         uno::RuntimeException)
 {
-    OSL_ENSURE(false,
-        "SwXParagraph::removeVetoableChangeListener(): not implemented");
+    OSL_FAIL("SwXParagraph::removeVetoableChangeListener(): not implemented");
 }
 
-//-----------------------------------------------------------------------------
 beans::PropertyState lcl_SwXParagraph_getPropertyState(
 //							SwUnoCrsr& rUnoCrsr,
                             const SwTxtNode& rTxtNode,
@@ -986,21 +903,18 @@ throw (beans::UnknownPropertyException)
         break;
     lcl_SwXParagraph_getPropertyStateDEFAULT:
     default:
-        if((*ppSet) && SFX_ITEM_SET == (*ppSet)->GetItemState(rEntry.nWID, FALSE))
+        if((*ppSet) && SFX_ITEM_SET == (*ppSet)->GetItemState(rEntry.nWID, sal_False))
             eRet = beans::PropertyState_DIRECT_VALUE;
         break;
     }
     return eRet;
 }
 
-/*-- 05.03.99 11:37:30---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 beans::PropertyState SAL_CALL
 SwXParagraph::getPropertyState(const OUString& rPropertyName)
 throw (beans::UnknownPropertyException, uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     SwTxtNode & rTxtNode(m_pImpl->GetTxtNodeOrThrow());
 
@@ -1019,16 +933,13 @@ throw (beans::UnknownPropertyException, uno::RuntimeException)
         lcl_SwXParagraph_getPropertyState(rTxtNode, &pSet, *pEntry, bDummy);
     return eRet;
 }
-/*-- 05.03.99 11:37:32---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 
 uno::Sequence< beans::PropertyState > SAL_CALL
 SwXParagraph::getPropertyStates(
         const uno::Sequence< OUString >& PropertyNames)
 throw (beans::UnknownPropertyException, uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     SwTxtNode & rTxtNode(m_pImpl->GetTxtNodeOrThrow());
 
@@ -1066,14 +977,11 @@ throw (beans::UnknownPropertyException, uno::RuntimeException)
     return aRet;
 }
 
-/*-- 05.03.99 11:37:33---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 void SAL_CALL
 SwXParagraph::setPropertyToDefault(const OUString& rPropertyName)
 throw (beans::UnknownPropertyException, uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     SwTxtNode & rTxtNode(m_pImpl->GetTxtNodeOrThrow());
 
@@ -1143,15 +1051,12 @@ throw (beans::UnknownPropertyException, uno::RuntimeException)
     }
 }
 
-/*-- 05.03.99 11:37:33---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 uno::Any SAL_CALL
 SwXParagraph::getPropertyDefault(const OUString& rPropertyName)
 throw (beans::UnknownPropertyException, lang::WrappedTargetException,
     uno::RuntimeException)
 {
-    vos::OGuard g(Application::GetSolarMutex());
+    SolarMutexGuard g;
 
     SwTxtNode & rTxtNode(m_pImpl->GetTxtNodeOrThrow());
 
@@ -1181,27 +1086,21 @@ throw (beans::UnknownPropertyException, lang::WrappedTargetException,
     return aRet;
 }
 
-/*-- 11.12.98 08:12:51---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 void SAL_CALL
 SwXParagraph::attach(const uno::Reference< text::XTextRange > & /*xTextRange*/)
 throw (lang::IllegalArgumentException, uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     // SwXParagraph will only created in order to be inserted by
     // 'insertTextContentBefore' or 'insertTextContentAfter' therefore
     // they cannot be attached
     throw uno::RuntimeException();
 }
 
-/*-- 11.12.98 08:12:51---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 uno::Reference< text::XTextRange > SAL_CALL
 SwXParagraph::getAnchor() throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     SwTxtNode & rTxtNode(m_pImpl->GetTxtNodeOrThrow());
 
@@ -1214,12 +1113,9 @@ SwXParagraph::getAnchor() throw (uno::RuntimeException)
     return xRet;
 }
 
-/*-- 11.12.98 08:12:52---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 void SAL_CALL SwXParagraph::dispose() throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     SwTxtNode *const pTxtNode( m_pImpl->GetTxtNode() );
     if (pTxtNode)
@@ -1234,14 +1130,11 @@ void SAL_CALL SwXParagraph::dispose() throw (uno::RuntimeException)
     }
 }
 
-/*-- 11.12.98 08:12:52---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 void SAL_CALL SwXParagraph::addEventListener(
         const uno::Reference< lang::XEventListener > & xListener)
 throw (uno::RuntimeException)
 {
-    vos::OGuard g(Application::GetSolarMutex());
+    SolarMutexGuard g;
 
     if (!m_pImpl->GetTxtNode())
     {
@@ -1249,14 +1142,12 @@ throw (uno::RuntimeException)
     }
     m_pImpl->m_ListenerContainer.AddListener(xListener);
 }
-/*-- 11.12.98 08:12:53---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SAL_CALL SwXParagraph::removeEventListener(
         const uno::Reference< lang::XEventListener > & xListener)
 throw (uno::RuntimeException)
 {
-    vos::OGuard g(Application::GetSolarMutex());
+    SolarMutexGuard g;
 
     if (!m_pImpl->GetTxtNode() ||
         !m_pImpl->m_ListenerContainer.RemoveListener(xListener))
@@ -1265,13 +1156,10 @@ throw (uno::RuntimeException)
     }
 }
 
-/*-- 11.12.98 08:12:53---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 uno::Reference< container::XEnumeration >  SAL_CALL
 SwXParagraph::createEnumeration() throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     SwTxtNode & rTxtNode(m_pImpl->GetTxtNodeOrThrow());
 
@@ -1283,40 +1171,29 @@ SwXParagraph::createEnumeration() throw (uno::RuntimeException)
     return xRef;
 }
 
-/*-- 11.12.98 08:12:54---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 uno::Type SAL_CALL SwXParagraph::getElementType() throw (uno::RuntimeException)
 {
     return text::XTextRange::static_type();
 }
-/*-- 11.12.98 08:12:54---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SAL_CALL SwXParagraph::hasElements() throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     return (GetTxtNode()) ? sal_True : sal_False;
 }
 
-/*-- 11.12.98 08:12:55---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 uno::Reference< text::XText > SAL_CALL
 SwXParagraph::getText() throw (uno::RuntimeException)
 {
-    vos::OGuard g(Application::GetSolarMutex());
+    SolarMutexGuard g;
 
     return m_pImpl->m_xParentText;
 }
 
-/*-- 11.12.98 08:12:55---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 uno::Reference< text::XTextRange > SAL_CALL
 SwXParagraph::getStart() throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     SwTxtNode & rTxtNode(m_pImpl->GetTxtNodeOrThrow());
 
@@ -1329,13 +1206,11 @@ SwXParagraph::getStart() throw (uno::RuntimeException)
         new SwXTextRange(aPam, xParent);
     return xRet;
 }
-/*-- 11.12.98 08:12:56---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 uno::Reference< text::XTextRange > SAL_CALL
 SwXParagraph::getEnd() throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     SwTxtNode & rTxtNode(m_pImpl->GetTxtNodeOrThrow());
 
@@ -1349,12 +1224,9 @@ SwXParagraph::getEnd() throw (uno::RuntimeException)
     return xRet;
 }
 
-/*-- 11.12.98 08:12:56---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 OUString SAL_CALL SwXParagraph::getString() throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     OUString aRet;
     SwTxtNode const*const pTxtNode( GetTxtNode() );
     if (pTxtNode)
@@ -1374,13 +1246,11 @@ OUString SAL_CALL SwXParagraph::getString() throw (uno::RuntimeException)
     }
     return aRet;
 }
-/*-- 11.12.98 08:12:57---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SAL_CALL SwXParagraph::setString(const OUString& aString)
 throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     SwTxtNode const*const pTxtNode( GetTxtNode() );
     if (pTxtNode)
@@ -1407,16 +1277,13 @@ throw (uno::RuntimeException)
     }
 }
 
-/* -----------------23.03.99 12:49-------------------
- *
- * --------------------------------------------------*/
 uno::Reference< container::XEnumeration > SAL_CALL
 SwXParagraph::createContentEnumeration(const OUString& rServiceName)
 throw (uno::RuntimeException)
 {
-    vos::OGuard g(Application::GetSolarMutex());
+    SolarMutexGuard g;
 
-    if (!rServiceName.equalsAscii("com.sun.star.text.TextContent"))
+    if (!rServiceName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.text.TextContent")))
     {
         throw uno::RuntimeException();
     }
@@ -1429,9 +1296,7 @@ throw (uno::RuntimeException)
         new SwXParaFrameEnumeration(aPam, PARAFRAME_PORTION_PARAGRAPH);
     return xRet;
 }
-/* -----------------23.03.99 12:49-------------------
- *
- * --------------------------------------------------*/
+
 uno::Sequence< OUString > SAL_CALL
 SwXParagraph::getAvailableServiceNames() throw (uno::RuntimeException)
 {
@@ -1441,7 +1306,6 @@ SwXParagraph::getAvailableServiceNames() throw (uno::RuntimeException)
     return aRet;
 }
 
-
 // MetadatableMixin
 ::sfx2::Metadatable* SwXParagraph::GetCoreObject()
 {
@@ -1460,3 +1324,4 @@ uno::Reference<frame::XModel> SwXParagraph::GetModel()
     return 0;
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
