@@ -60,6 +60,7 @@
 #include "xmlithlp.hxx"
 #include <com/sun/star/uno/Any.hxx>
 
+using ::editeng::SvxBorderLine;
 using ::rtl::OUString;
 using namespace ::com::sun::star;
 using namespace ::xmloff::token;
@@ -67,7 +68,7 @@ using uno::Any;
 
 SvXMLImportItemMapper::SvXMLImportItemMapper(
                                 SvXMLItemMapEntriesRef rMapEntries,
-                                USHORT nUnknWhich ) :
+                                sal_uInt16 nUnknWhich ) :
     mrMapEntries( rMapEntries ),
     nUnknownWhich( nUnknWhich )
 {
@@ -83,14 +84,14 @@ void SvXMLImportItemMapper::importXML( SfxItemSet& rSet,
                                       const SvXMLUnitConverter& rUnitConverter,
                                        const SvXMLNamespaceMap& rNamespaceMap ) const
 {
-    INT16 nAttr = xAttrList->getLength();
+    sal_Int16 nAttr = xAttrList->getLength();
 
     SvXMLAttrContainerItem *pUnknownItem = 0;
-    for( INT16 i=0; i < nAttr; i++ )
+    for( sal_Int16 i=0; i < nAttr; i++ )
     {
         const OUString& rAttrName = xAttrList->getNameByIndex( i );
         OUString aLocalName, aPrefix, aNamespace;
-        USHORT nPrefix =
+        sal_uInt16 nPrefix =
             rNamespaceMap.GetKeyByAttrName( rAttrName, &aPrefix, &aLocalName,
                                             &aNamespace );
         if( XML_NAMESPACE_XMLNS == nPrefix )
@@ -109,7 +110,7 @@ void SvXMLImportItemMapper::importXML( SfxItemSet& rSet,
             {
                 // first get item from itemset
                 const SfxPoolItem* pItem = 0;
-                SfxItemState eState = rSet.GetItemState( pEntry->nWhichId, TRUE,
+                SfxItemState eState = rSet.GetItemState( pEntry->nWhichId, sal_True,
                                                          &pItem );
 
                 // if its not set, try the pool
@@ -120,13 +121,10 @@ void SvXMLImportItemMapper::importXML( SfxItemSet& rSet,
                 if(eState >= SFX_ITEM_DEFAULT && pItem)
                 {
                     SfxPoolItem *pNewItem = pItem->Clone();
-                    BOOL bPut = FALSE;
+                    sal_Bool bPut = sal_False;
 
                     if( 0 == (pEntry->nMemberId&MID_SW_FLAG_SPECIAL_ITEM_IMPORT) )
                     {
-// 						bPut = pNewItem->importXML( rValue,
-// 											pEntry->nMemberId & MID_SW_FLAG_MASK,
-// 											rUnitConverter );
                         bPut = PutXMLValue( *pNewItem, rValue,
                                             static_cast<sal_uInt16>( pEntry->nMemberId & MID_SW_FLAG_MASK ),
                                             rUnitConverter );
@@ -146,7 +144,7 @@ void SvXMLImportItemMapper::importXML( SfxItemSet& rSet,
                 }
                 else
                 {
-                    DBG_ERROR( "Could not get a needed item for xml import!" );
+                    OSL_FAIL( "Could not get a needed item for xml import!" );
                 }
             }
             else if( 0 != (pEntry->nMemberId & MID_SW_FLAG_NO_ITEM_IMPORT) )
@@ -160,7 +158,7 @@ void SvXMLImportItemMapper::importXML( SfxItemSet& rSet,
             if( !pUnknownItem )
             {
                 const SfxPoolItem* pItem = 0;
-                if( SFX_ITEM_SET == rSet.GetItemState( nUnknownWhich, TRUE,
+                if( SFX_ITEM_SET == rSet.GetItemState( nUnknownWhich, sal_True,
                                                        &pItem ) )
                 {
                     SfxPoolItem *pNew = pItem->Clone();
@@ -197,7 +195,7 @@ void SvXMLImportItemMapper::importXML( SfxItemSet& rSet,
 
 /** this method is called for every item that has the
     MID_SW_FLAG_SPECIAL_ITEM_IMPORT flag set */
-BOOL
+sal_Bool
 SvXMLImportItemMapper::handleSpecialItem(  const SvXMLItemMapEntry& /*rEntry*/,
                                             SfxPoolItem& /*rItem*/,
                                             SfxItemSet& /*rSet*/,
@@ -205,20 +203,20 @@ SvXMLImportItemMapper::handleSpecialItem(  const SvXMLItemMapEntry& /*rEntry*/,
                                             const SvXMLUnitConverter& /*rUnitConverter*/,
                                             const SvXMLNamespaceMap& /*rNamespaceMap*/ ) const
 {
-    DBG_ERROR( "unsuported special item in xml import" );
-    return FALSE;
+    OSL_FAIL( "unsuported special item in xml import" );
+    return sal_False;
 }
 
 /** this method is called for every item that has the
     MID_SW_FLAG_NO_ITEM_IMPORT flag set */
-BOOL SvXMLImportItemMapper::handleNoItem( const SvXMLItemMapEntry& /*rEntry*/,
+sal_Bool SvXMLImportItemMapper::handleNoItem( const SvXMLItemMapEntry& /*rEntry*/,
                                            SfxItemSet& /*rSet*/,
                                            const OUString& /*rValue*/,
                                            const SvXMLUnitConverter& /*rUnitConverter*/,
                                            const SvXMLNamespaceMap& /*rNamespaceMap*/ ) const
 {
-    DBG_ERROR( "unsuported no item in xml import" );
-    return FALSE;
+    OSL_FAIL( "unsuported no item in xml import" );
+    return sal_False;
 }
 
 void SvXMLImportItemMapper::finished( SfxItemSet& ) const
@@ -295,7 +293,7 @@ sal_Bool SvXMLImportItemMapper::PutXMLValue(
                 break;
 
                 default:
-                    DBG_ERROR( "unknown member id!");
+                    OSL_FAIL( "unknown member id!");
             }
         }
         break;
@@ -322,7 +320,7 @@ sal_Bool SvXMLImportItemMapper::PutXMLValue(
                     pULSpace->SetLower( (sal_uInt16)nAbs, (sal_uInt16)nProp );
                     break;
                 default:
-                    DBG_ERROR("unknown MemberId");
+                    OSL_FAIL("unknown MemberId");
             }
         }
         break;
@@ -392,7 +390,7 @@ sal_Bool SvXMLImportItemMapper::PutXMLValue(
                         if( nX < 0 ) nX *= -1;
                         if( nY < 0 ) nY *= -1;
 
-                        pShadow->SetWidth( static_cast< USHORT >( (nX + nY) >> 1 ) );
+                        pShadow->SetWidth( static_cast< sal_uInt16 >( (nX + nY) >> 1 ) );
                     }
                 }
             }
@@ -508,25 +506,19 @@ sal_Bool SvXMLImportItemMapper::PutXMLValue(
                     if( !aTokenEnum.getNextToken( aToken ) )
                         return sal_False;
 
-                    if( !rUnitConverter.convertMeasure( nInWidth, aToken,
-                                                        DEF_LINE_WIDTH_0,
-                                                        DEF_LINE_WIDTH_4 ) )
+                    if( !rUnitConverter.convertMeasure( nInWidth, aToken ) )
                         return sal_False;
 
                     if( !aTokenEnum.getNextToken( aToken ) )
                         return sal_False;
 
-                    if( !rUnitConverter.convertMeasure( nDistance, aToken,
-                                                        DEF_LINE_WIDTH_0,
-                                                        DEF_LINE_WIDTH_4 ) )
+                    if( !rUnitConverter.convertMeasure( nDistance, aToken ) )
                         return sal_False;
 
                     if( !aTokenEnum.getNextToken( aToken ) )
                         return sal_False;
 
-                    if( !rUnitConverter.convertMeasure( nOutWidth, aToken,
-                                                        DEF_LINE_WIDTH_0,
-                                                        DEF_LINE_WIDTH_4 ) )
+                    if( !rUnitConverter.convertMeasure( nOutWidth, aToken ) )
                         return sal_False;
                         
                     // #i61946: accept line style even it's not part of our "normal" set of line styles
@@ -597,12 +589,12 @@ sal_Bool SvXMLImportItemMapper::PutXMLValue(
                 switch( nMemberId )
                 {
                     case MID_BREAK_BEFORE:
-                        pFmtBreak->SetValue( static_cast< USHORT >((eEnum == 1) ?
+                        pFmtBreak->SetValue( static_cast< sal_uInt16 >((eEnum == 1) ?
                                              SVX_BREAK_COLUMN_BEFORE :
                                              SVX_BREAK_PAGE_BEFORE) );
                         break;
                     case MID_BREAK_AFTER:
-                        pFmtBreak->SetValue( static_cast< USHORT >((eEnum == 1) ?
+                        pFmtBreak->SetValue( static_cast< sal_uInt16 >((eEnum == 1) ?
                                              SVX_BREAK_COLUMN_AFTER :
                                              SVX_BREAK_PAGE_AFTER) );
                         break;
@@ -784,7 +776,7 @@ sal_Bool SvXMLImportItemMapper::PutXMLValue(
                 sal_Int32 nVal;
                 bOk = rUnitConverter.convertNumber( nVal, rValue, 0, USHRT_MAX );
                 if( bOk )
-                    pPageDesc->SetNumOffset( (USHORT)nVal );
+                    pPageDesc->SetNumOffset( (sal_uInt16)nVal );
             }
         }
         break;
@@ -965,7 +957,7 @@ sal_Bool SvXMLImportItemMapper::PutXMLValue(
         break;
 
         default:
-            DBG_ERROR("Item not implemented!");
+            OSL_FAIL("Item not implemented!");
         break;
    }
 
